@@ -18,10 +18,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include "base_db_table_data.h"
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/application.h>
-#include "python_embed/glom_python.h"
+#include <glom/python_embed/glom_python.h>
 #include <glom/utils_ui.h>
 #include <sstream>
 #include <glibmm/i18n.h>
@@ -48,7 +49,7 @@ bool Base_DB_Table_Data::refresh_data_from_database()
 Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data_field_only(const sharedptr<const Field>& field) const
 {
   sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-  layout_item->set_full_field_details(field); 
+  layout_item->set_full_field_details(field);
 
   return get_entered_field_data(layout_item);
 }
@@ -62,7 +63,7 @@ Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data(const sharedptr<con
 
 Gtk::TreeModel::iterator Base_DB_Table_Data::get_row_selected()
 {
-  //This in meaningless for Details, 
+  //This in meaningless for Details,
   //but is overridden for list views.
   return Gtk::TreeModel::iterator();
 }
@@ -117,16 +118,26 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
           //We need the connection when we run the script, so that the script may use it.
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
           // TODO: Is this function supposed to throw an exception?
-          sharedptr<SharedConnection> sharedconnection = connect_to_server(App_Glom::get_application());
+          sharedptr<SharedConnection> sharedconnection = connect_to_server(Application::get_application());
 #else
           std::auto_ptr<ExceptionConnection> error;
-          sharedptr<SharedConnection> sharedconnection = connect_to_server(App_Glom::get_application(), error);
-          if(error.get() == NULL)
+          sharedptr<SharedConnection> sharedconnection = connect_to_server(Application::get_application(), error);
+          if(!error.get())
           {
             // Don't evaluate function on error
 #endif // GLIBMM_EXCEPTIONS_ENABLED
 
-            const Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field->get_glom_type(), calculation, field_values, document, m_table_name, sharedconnection->get_gda_connection());
+            Glib::ustring error_message; //TODO: Check this.
+            const Gnome::Gda::Value value =
+              glom_evaluate_python_function_implementation(
+                field->get_glom_type(),
+                calculation,
+                field_values,
+                document,
+                m_table_name,
+                fieldPrimaryKey, primary_key_value,
+                sharedconnection->get_gda_connection(),
+                error_message);
             set_entered_field_data(layout_item, value);
 #ifndef GLIBMM_EXCEPTIONS_ENABLED
           }
@@ -156,7 +167,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
   typedef std::map<Glib::ustring, bool> type_map_added;
   type_map_added map_added;
   Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
-  
+
   for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
   {
     sharedptr<LayoutItem_Field> layout_item = *iter;
@@ -168,7 +179,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
       {
         Gnome::Gda::Value value;
 
-        const sharedptr<const Field>& field = layout_item->get_full_field_details();        
+        const sharedptr<const Field>& field = layout_item->get_full_field_details();
         if(field)
         {
           //Use the specified (generated) primary key value, if there is one:
@@ -189,7 +200,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
             if(!get_field_value_is_unique(m_table_name, layout_item, value))
             {
               //Ignore this field value. TODO: Warn the user about it.
-            } 
+            }
           }
           */
           if(!value.is_null())
@@ -199,12 +210,12 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
               strNames += ", ";
               strValues += ", ";
             }
-  
+
             strNames += "\"" + field_name + "\"";
             strValues += field->get_gda_holder_string();
             Glib::RefPtr<Gnome::Gda::Holder> holder = field->get_holder(value);
             params->add_holder(holder);
-  
+
             map_added[field_name] = true;
           }
         }
@@ -228,7 +239,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
       for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
       {
         sharedptr<const LayoutItem_Field> layout_item = *iter;
-         
+
         //TODO_Performance: We just set this with set_entered_field_data() above. Maybe we could just remember it.
         const Gnome::Gda::Value field_value = get_entered_field_data(layout_item);
 
@@ -255,7 +266,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
 bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relationship>& relationship, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value)
 {
-  BusyCursor cursor(App_Glom::get_application());
+  BusyCursor cursor(Application::get_application());
 
   bool result = false;
 
@@ -283,9 +294,9 @@ bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relatio
   return result;
 }
 
-bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const LayoutItem_Field>& layout_item_parent, 
-  const sharedptr<const Relationship>& relationship, 
-  const sharedptr<const Field>& primary_key_field, 
+bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const LayoutItem_Field>& layout_item_parent,
+  const sharedptr<const Relationship>& relationship,
+  const sharedptr<const Field>& primary_key_field,
   const Gnome::Gda::Value& primary_key_value_provided,
   Gnome::Gda::Value& primary_key_value_used)
 {
@@ -298,7 +309,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
     primary_key_value_used = primary_key_value; //Let the caller know what related record was created.
     return true;
   }
-    
+
 
   //To store the entered data in the related field, we would first have to create a related record.
   if(!relationship->get_auto_create())
@@ -306,12 +317,13 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
     //Warn the user:
     //TODO: Make the field insensitive until it can receive data, so people never see this dialog.
     const Glib::ustring message = _("Data may not be entered into this related field, because the related record does not yet exist, and the relationship does not allow automatic creation of new related records.");
+#undef GLOM_ENABLE_MAEMO
 #ifdef GLOM_ENABLE_MAEMO
-    Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *App_Glom::get_application(), message);
+    Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *Application::get_application(), message);
 #else
     Gtk::MessageDialog dialog(Utils::bold_message(_("Related Record Does Not Exist")), true);
     dialog.set_secondary_text(message);
-    dialog.set_transient_for(*App_Glom::get_application());
+    dialog.set_transient_for(*Application::get_application());
 #endif
     dialog.run();
 
@@ -332,12 +344,12 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
       const Glib::ustring message = _("Data may not be entered into this related field, because the related record does not yet exist, and the key in the related record is auto-generated and therefore can not be created with the key value in this record.");
 
 #ifdef GLOM_ENABLE_MAEMO
-      Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *App_Glom::get_application(), message);
+      Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *Application::get_application(), message);
 #else
       Gtk::MessageDialog dialog(Utils::bold_message(_("Related Record Cannot Be Created")), true);
       //TODO: This is a very complex error message:
       dialog.set_secondary_text(message);
-      dialog.set_transient_for(*App_Glom::get_application());
+      dialog.set_transient_for(*Application::get_application());
 #endif
       dialog.run();
 
@@ -412,7 +424,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
           }
         }
       }
-        
+
       primary_key_value_used = primary_key_value; //Let the caller know what related record was created.
       return true;
     }
@@ -422,14 +434,14 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
 void Base_DB_Table_Data::on_record_added(const Gnome::Gda::Value& /* primary_key_value */, const Gtk::TreeModel::iterator& /* row */)
 {
    //Overridden by some derived classes.
-  
+
    signal_record_changed().emit();
 }
 
 void Base_DB_Table_Data::on_record_deleted(const Gnome::Gda::Value& /* primary_key_value */)
 {
   //Overridden by some derived classes.
-  
+
   signal_record_changed().emit();
 }
 
@@ -442,7 +454,7 @@ bool Base_DB_Table_Data::confirm_delete_record()
 #else
   Gtk::MessageDialog dialog(Utils::bold_message(_("Delete record")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
   dialog.set_secondary_text(message);
-  dialog.set_transient_for(*App_Glom::get_application());
+  dialog.set_transient_for(*Application::get_application());
 #endif
   dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   dialog.add_button(Gtk::Stock::DELETE, Gtk::RESPONSE_OK);
@@ -508,9 +520,14 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
           std::cerr << "Base_DB_Table_Data::refresh_related_fields(): The result had 0 columns" << std::endl;
         }
 
-        for(guint uiCol = 0; uiCol < cols_count; uiCol++)
+        for(guint uiCol = 0; uiCol < cols_count; ++uiCol)
         {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
           const Gnome::Gda::Value value = result->get_value_at(uiCol, 0 /* row */);
+#else
+          std::auto_ptr<Glib::Error> value_error;
+          const Gnome::Gda::Value value = result->get_value_at(uiCol, 0 /* row */, value_error);
+#endif
           sharedptr<LayoutItem_Field> layout_item = *iterFields;
           if(!layout_item)
             std::cerr << "Base_DB_Table_Data::refresh_related_fields(): The layout_item was null." << std::endl;
@@ -568,5 +585,3 @@ Base_DB_Table_Data::type_vecLayoutFields Base_DB_Table_Data::get_related_fields(
 }
 
 } //namespace Glom
-
-
